@@ -46,39 +46,39 @@ pub struct CMumbleLink {
 }
 #[derive(Debug, Clone, Copy)]
 #[repr(C)]
-struct MumbleContext {
+pub struct MumbleContext {
     //the 48 bytes Mumble uses for identification
-    server_address: [u8; 28], // contains sockaddr_in or sockaddr_in6
-    map_id: u32,
-    map_type: u32,
-    shard_id: u32,
-    instance: u32,
-    build_id: u32,
+    pub server_address: [u8; 28], // contains sockaddr_in or sockaddr_in6
+    pub map_id: u32,
+    pub map_type: u32,
+    pub shard_id: u32,
+    pub instance: u32,
+    pub build_id: u32,
     // Additional data that gw2 provides us
-    ui_state: u32, // Bitmask: Bit 1 = IsMapOpen, Bit 2 = IsCompassTopRight, Bit 3 = DoesCompassHaveRotationEnabled, Bit 4 = Game has focus, Bit 5 = Is in Competitive game mode, Bit 6 = Textbox has focus, Bit 7 = Is in Combat
-    compass_width: u16, // pixels
-    compass_height: u16, // pixels
-    compass_rotation: f32, // radians
-    player_x: f32, // continentCoords
-    player_y: f32, // continentCoords
-    map_center_x: f32, // continentCoords
-    map_center_y: f32, // continentCoords
-    map_scale: f32,
-    process_id: u32,
-    mount_index: u8,
+    pub ui_state: u32, // Bitmask: Bit 1 = IsMapOpen, Bit 2 = IsCompassTopRight, Bit 3 = DoesCompassHaveRotationEnabled, Bit 4 = Game has focus, Bit 5 = Is in Competitive game mode, Bit 6 = Textbox has focus, Bit 7 = Is in Combat
+    pub compass_width: u16, // pixels
+    pub compass_height: u16, // pixels
+    pub compass_rotation: f32, // radians
+    pub player_x: f32, // continentCoords
+    pub player_y: f32, // continentCoords
+    pub map_center_x: f32, // continentCoords
+    pub map_center_y: f32, // continentCoords
+    pub map_scale: f32,
+    pub process_id: u32,
+    pub mount_index: u8,
 }
 #[derive(Serialize, Deserialize)]
 pub struct Identity {
-    name: String,
-    profession: u8,
-    spec: u8,
-    race: u8,
-    map_id: u16,
-    world_id: u16,
-    team_color_id: u16,
-    commander: bool,
-    fov: f32,
-    uisz: u8,
+    pub name: String,
+    pub profession: u8,
+    pub spec: u8,
+    pub race: u8,
+    pub map_id: u16,
+    pub world_id: u16,
+    pub team_color_id: u16,
+    pub commander: bool,
+    pub fov: f32,
+    pub uisz: u8,
 }
 #[derive(Debug, Clone, Copy)]
 pub struct MumbleLink {
@@ -95,7 +95,20 @@ pub struct MumbleLink {
     pub context_len: u32,
     pub context: [u8; 85],
 }
+impl MumbleLink {
+    pub fn get_identity(&self) -> Identity {
+        let id = String::from_utf16(&self.identity).unwrap();
+        let id : Identity = serde_json::from_str(&id).unwrap();
+        id
 
+    }
+
+    pub fn get_context(&self) -> MumbleContext {
+        unsafe {
+        std::ptr::read_volatile(&self.context as *const u8 as * const MumbleContext)
+        }
+    }
+}
 impl CMumbleLink {
     #[cfg(target_os = "windows")]
     pub fn new(key: &str) -> *const CMumbleLink {
